==> qmmp_0.4.1.orig.tar.gz: qmmp-0.4.1/src/plugins/Transports/http/translations/http_plugin_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="lt">
<context>
    <name>HTTPInputFactory</name>
    <message>
        <location filename="../httpinputfactory.cpp" line="34"/>
        <source>HTTP Plugin</source>
        <translation>HTTP įskiepis</translation>
    </message>
    <message>
        <location filename="../httpinputfactory.cpp" line="54"/>
        <source>About HTTP Transport Plugin</source>
        <translation>Apie HTTP transporto įskiepį</translation>
    </message>
    <message>
        <location filename="../httpinputfactory.cpp" line="55"/>
        <source>Qmmp HTTP Transport Plugin</source>
        <translation>Qmmp HTTP transporto įskiepis</translation>
    </message>
    <message>
        <location filename="../httpinputfactory.cpp" line="56"/>
        <source>Compiled against libcurl-%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../httpinputfactory.cpp" line="57"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Sukūrė: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>HTTP Plugin Settings</source>
        <translation>HTTP įskiepio nustatymai</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Buffer size:</source>
        <translation>Buferio dydis:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="64"/>
        <source>KB</source>
        <translation>КB</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="78"/>
        <source>Metadata encoding</source>
        <translation>Metaduomenų kodavimas</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="84"/>
        <source>Automatic charset detection</source>
        <translation>Automatinis kodavimo aptikimas</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="94"/>
        <source>Language:</source>
        <translation>Kalba</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="114"/>
        <source>Default encoding:</source>
        <translation>Kodavimas pagal nutylėjimą</translation>
    </message>
</context>
</TS>

==> qmmp_0.5.5.orig.tar.gz: qmmp-0.5.5/src/plugins/Transports/http/translations/http_plugin_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="lt">
<context>
    <name>HTTPInputFactory</name>
    <message>
        <location filename="../httpinputfactory.cpp" line="34"/>
        <source>HTTP Plugin</source>
        <translation>HTTP įskiepis</translation>
    </message>
    <message>
        <location filename="../httpinputfactory.cpp" line="54"/>
        <source>About HTTP Transport Plugin</source>
        <translation>Apie HTTP transporto įskiepį</translation>
    </message>
    <message>
        <location filename="../httpinputfactory.cpp" line="55"/>
        <source>Qmmp HTTP Transport Plugin</source>
        <translation>Qmmp HTTP transporto įskiepis</translation>
    </message>
    <message>
        <location filename="../httpinputfactory.cpp" line="56"/>
        <source>Compiled against libcurl-%1</source>
        <translation>Sukompiliuota su libcurl-%1</translation>
    </message>
    <message>
        <location filename="../httpinputfactory.cpp" line="57"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Sukūrė: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>HTTP Plugin Settings</source>
        <translation>HTTP įskiepio nustatymai</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Buffer size:</source>
        <translation>Buferio dydis:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="64"/>
        <source>KB</source>
        <translation>КB</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="78"/>
        <source>Metadata encoding</source>
        <translation>Metaduomenų kodavimas</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="84"/>
        <source>Automatic charset detection</source>
        <translation>Automatinis kodavimo aptikimas</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="94"/>
        <source>Language:</source>
        <translation>Kalba</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="114"/>
        <source>Default encoding:</source>
        <translation>Kodavimas pagal nutylėjimą</translation>
    </message>
</context>
</TS>
